==> nzbget-0.2.0.tar.gz: nzbget-0.2.0/SingleServerPool.h <==
/*
 *  This file if part of nzbget
 *
 *  Copyright (C) 2004  Sven Henkel <sidddy@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Revision: 1.2 $
 * $Date: 2004/07/13 21:52:50 $
 *
 */

/*
 *
 *  Semaphore Patch by Florian Penzkofer <f.penzkofer@sent.com>
 *  The queue of mutexes that was used did not work for every
 *  implementation of POSIX threads. Now a Semaphore is used.
 *  
 */


#ifndef SINGLESERVERPOOL_H
#define SINGLESERVERPOOL_H

#include <list>
#include <pthread.h>
#include <semaphore.h>

#include "NewsServer.h"
#include "NNTPConnection.h"

class SingleServerPool 
{
 public:

    SingleServerPool(NewsServer* s, int max);

    NNTPConnection* getConnection();

    void freeConnection(NNTPConnection* con);

 private:

    int getID();
    
    NewsServer* server;

    int max;

    std::vector< NNTPConnection* > connections;

    int id;

    std::list<int> free;
    
    pthread_mutex_t free_mutex;
    
    sem_t semaphore;
};

#endif

==> nzbget-0.2.2.tar.gz: nzbget-0.2.2/SingleServerPool.h <==
/*
 *  This file if part of nzbget
 *
 *  Copyright (C) 2004  Sven Henkel <sidddy@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Revision: 1.7 $
 * $Date: 2005/07/12 09:37:48 $
 *
 */

/*
 *
 *  Semaphore Patch by Florian Penzkofer <f.penzkofer@sent.com>
 *  The queue of mutexes that was used did not work for every
 *  implementation of POSIX threads. Now a Semaphore is used.
 *  
 */


#ifndef SINGLESERVERPOOL_H
#define SINGLESERVERPOOL_H

#include <list>
#include <pthread.h>
#include <semaphore.h>

#include "NewsServer.h"
#include "NNTPConnection.h"

class SingleServerPool 
{
	NewsServer*  					m_pNewsServer;

	std::vector< NNTPConnection* >	m_Connections;
	std::vector< pthread_mutex_t* >	m_Queue;
	std::list< int >				m_FreeConnections;

	int 							m_iId;
	int 							m_iMax;

	pthread_mutex_t 				m_MutexFree;

	sem_t 							m_Semaphore;
public:
									SingleServerPool();
									SingleServerPool(NewsServer* s, int max);

	NNTPConnection*					GetConnection();
	void 							FreeConnection(NNTPConnection* con);
private:
	int 							GetID();
};


#endif
